# kinnaird-utils

My personal helper methods.

[https://github.com/kmcquade/kinnaird-utils](https://github.com/kmcquade/kinnaird-utils)

[![Downloads](https://pepy.tech/badge/kinnaird-utils)](https://pepy.tech/project/kinnaird-utils)

## Motivation

I forget how to do plenty of Python things regularly that I have solved before and find myself wasting time looking through old code to figure out how I did something in the past. I am storing some helper methods in this package, so I can use them during rapid development of stuff.


## Process

* Use this package when developing rapidly
* When I have my tools in a more usable state, I can eliminate the tool's dependency on `kinnaird-utils` by simply copying over the helper methods to the tool I am working on.

